==> osam_flutter-3.2.6.tar.gz: lib/src/navigation/navigation.dart <==
import 'package:flutter/foundation.dart';
import 'package:osam/osam.dart';
import 'package:osam_flutter/src/navigation/osam_route.dart';

import '../../osam_flutter.dart';

part 'navigation.g.dart';

class NoRouteException implements Exception {}

@HiveType(typeId: 222)
class Navigation with PropertyChanger {
  @HiveField(0)
  final List<OsamRoute<Object>> _routes;
  final IProperty<List<OsamRoute<Object>>> routes;

  Navigation(this._routes) : routes = IProperty(_routes);

  Future<R> push<R>(OsamRoute<R> route) {
    update(routes, (value) => value.add(route));
    return route.whenComplete;
  }

  void pop() => update(routes, (value) => value.removeLast());

  T findRoute<T extends OsamRoute>() =>
      _routes.firstWhere((element) => element is T);

  Future<R> pushReplacement<R>(OsamRoute<R> route) {
    update(routes, (value) {
      value.removeLast();
      value.add(route);
    });
    return route.whenComplete;
  }

  Future<R> pushAndRemoveUntil<R>(OsamRoute<R> route) {
    update(routes, (value) {
      value.clear();
      value.add(route);
    });
    return route.whenComplete;
  }

  void popUntil<T extends OsamRoute>() => update(routes, (value) {
        if (value.contains(T)) {
          while (!(value.last is T)) {
            value.removeLast();
          }
        }
      });
}

@HiveType(typeId: 221)
class TabNavigation with PropertyChanger {
  @HiveField(0)
  String _tab;
  final IProperty<String> tabNotifier;

  TabNavigation(this._tab) : tabNotifier = IProperty(_tab);

  set tab(String tab) {
    _tab = tab;
    set(tabNotifier, _tab);
  }
}

==> osam_flutter-3.2.8.tar.gz: lib/src/navigation/navigation.dart <==
import 'package:flutter/foundation.dart';
import 'package:osam/osam.dart';
import 'package:osam_flutter/src/navigation/osam_route.dart';

import '../../osam_flutter.dart';

part 'navigation.g.dart';

class NoRouteException implements Exception {}

@HiveType(typeId: 222)
class Navigation extends PropertyChanger {
  @HiveField(0)
  final List<OsamRoute<Object>> _routes;
  final IProperty<List<OsamRoute<Object>>> routes;

  Navigation(this._routes) : routes = IProperty(_routes);

  Future<R> push<R>(OsamRoute<R> route) {
    let(routes).apply((value) => value.add(route));
    return route.whenComplete;
  }

  void pop() => let(routes).apply((value) => value.removeLast());

  T findRoute<T extends OsamRoute>() =>
      _routes.firstWhere((element) => element is T);

  Future<R> pushReplacement<R>(OsamRoute<R> route) {
    let(routes).apply((value) {
      value.removeLast();
      value.add(route);
    });
    return route.whenComplete;
  }

  Future<R> pushAndRemoveUntil<R>(OsamRoute<R> route) {
    let(routes).apply((value) {
      value.clear();
      value.add(route);
    });
    return route.whenComplete;
  }

  void popUntil<T extends OsamRoute>() => let(routes).apply((value) {
        if (value.contains(T)) {
          while (!(value.last is T)) {
            value.removeLast();
          }
        }
      });
}

@HiveType(typeId: 221)
class TabNavigation extends PropertyChanger {
  @HiveField(0)
  String _tab;
  final IProperty<String> tabNotifier;

  TabNavigation(this._tab) : tabNotifier = IProperty(_tab);

  set tab(String tab) {
    _tab = tab;
    let(tabNotifier).apply((value) => value = _tab);
  }
}
